@@ -1,4 +1,4 @@
-from easydev.decorators import requires
+from easydev.decorators import requires, ifpandas
 
 class A(object):
 
@@ -11,11 +11,11 @@ class A(object):
 
     @requires("a", "what to do")
     def print_str(self):
-        print self.a
+        print(self.a)
 
     @requires(["a",'b'], "what to do")
     def print_list(self):
-        print self.a +self.b
+        print(self.a +self.b)
 
 
 def test():
@@ -35,5 +35,6 @@ def test():
     a.print_str()
     a.print_list()
 
-
-
+@ifpandas
+def test_deco_pandas(self):
+    print(1)
